@@ -6,7 +6,7 @@
 void		*abook_malloc(size_t size);
 void		*abook_realloc(void *ptr, size_t size);
 FILE		*abook_fopen (const char *path, const char *mode);
-void		quit_abook();
+void		quit_abook(int save_db);
 void		launch_wwwbrowser(int item);
 void		launch_mutt(int item);
 void		print_stderr(int item);
@@ -28,6 +28,9 @@ int		strncasecmp (const char *, const char *, size_t);
 
 #define RCFILE		"abookrc"
 
+#define QUIT_SAVE	1
+#define QUIT_DONTSAVE	0
+
 /*
  * some "abookwide" useful macros
  */
@@ -35,10 +38,10 @@ int		strncasecmp (const char *, const char *, size_t);
 #define hide_cursor()	curs_set(0)
 #define show_cursor()	curs_set(1)
 
-#define safe_atoi(X)    (X == NULL) ? 0 : atoi(X)
+#define safe_atoi(X)    ((X == NULL) ? 0 : atoi(X))
 #define my_free(X)	do {free(X); X=NULL;} while(0)
-#define safe_str(X)	X == NULL ? "" : X
-#define safe_strdup(X)	(X == NULL) ? NULL : strdup(X)
+#define safe_str(X)	((X == NULL) ? "" : X)
+#define safe_strdup(X)	((X == NULL) ? NULL : strdup(X))
 
 #ifndef min
 #       define min(x,y) (((x)<(y)) ? (x):(y))
