@@ -1,5 +1,5 @@
 /*
- * $Id: abook_rl.c,v 1.8 2003/11/07 07:02:15 jheinonen Exp $
+ * $Id: abook_rl.c,v 1.11 2004/02/18 19:41:37 jheinonen Exp $
  *
  * by JH <jheinonen@users.sourceforge.net>
  *
@@ -31,6 +31,10 @@
 #       include <history.h>
 #endif
 
+#ifdef HANDLE_MULTIBYTE
+#	include <mbswidth.h>
+#endif
+
 #define RL_READLINE_NAME	"Abook"
 
 static int rl_x, rl_y;
@@ -45,10 +49,22 @@ rl_refresh()
 	wrefresh(rl_win);
 }
 
+#ifdef HANDLE_MULTIBYTE
+static int
+rline_calc_point()
+{
+	return (int)mbsnwidth(rl_line_buffer, rl_point, 0);
+}
+#endif
+
 static void
 rline_update()
 {	
+#ifdef HANDLE_MULTIBYTE
+	int real_point = rline_calc_point() + rl_x;
+#else
 	int real_point = rl_point + rl_x;
+#endif
 	
 	if(real_point > (COLS - 1))
 		mvwaddnstr(rl_win, rl_y, rl_x,
@@ -84,7 +100,9 @@ abook_rl_init(bool use_completion)
 {
 	rl_readline_name = RL_READLINE_NAME;
 	
+#if RL_VERSION_MAJOR >= 4
 	rl_already_prompted = 1;
+#endif
 	rl_catch_sigwinch = 0;
 	
 	rl_redisplay_function = rline_update;
