@@ -1,6 +1,6 @@
 
 /*
- * $Id: edit.c,v 1.26 2003/11/10 08:45:59 jheinonen Exp $
+ * $Id: edit.c,v 1.31 2004/01/26 11:35:30 jheinonen Exp $
  *
  * by JH <jheinonen@users.sourceforge.net>
  *
@@ -9,6 +9,7 @@
 
 #include <string.h>
 #include <stdlib.h>
+#include <assert.h>
 #include "abook_curses.h"
 #include "ui.h"
 #include "abook.h"
@@ -33,33 +34,35 @@ extern int items;
 WINDOW *editw;
 
 static void
-editor_tab(int tab)
+editor_tab(const int tab)
 {
 	int i;
-	char *tab_names[] = {
-		" CONTACT ",
-		" ADDRESS ",
-		"  PHONE  ",
-		"  OTHER  "
+	const int spacing = 12;
+	static char *tab_names[] = {
+		"CONTACT",
+		"ADDRESS",
+		" PHONE ",
+		" OTHER ",
+		"CUSTOM "
 	};
 
 	mvwhline(editw, TABLINE+1, 0, UI_HLINE_CHAR, EDITW_COLS);
 	for(i=0; i < TABS; i++) {
-		mvwaddch(editw,  TABLINE+1, 16 * i + 2,  UI_TEE_CHAR);
-		mvwaddch(editw,  TABLINE+1, 16 * i + 14, UI_TEE_CHAR);
+		mvwaddch(editw,  TABLINE+1, spacing * i + 2,  UI_TEE_CHAR);
+		mvwaddch(editw,  TABLINE+1, spacing * i + 12, UI_TEE_CHAR);
 	}
 
 	for(i=0; i < TABS; i++) {
-		mvwaddch(editw,  TABLINE, 16 * i + 2,  UI_ULCORNER_CHAR);
-		mvwaddch(editw,  TABLINE, 16 * i + 3,  UI_LBOXLINE_CHAR);
-		mvwaddstr(editw, TABLINE, 16 * i + 4,  tab_names[i]);
-		mvwaddch(editw,  TABLINE, 16 * i + 13, UI_RBOXLINE_CHAR);
-		mvwaddch(editw,  TABLINE, 16 * i + 14, UI_URCORNER_CHAR);
+		mvwaddch(editw,  TABLINE, spacing * i + 2,  UI_ULCORNER_CHAR);
+		mvwaddch(editw,  TABLINE, spacing * i + 3,  UI_LBOXLINE_CHAR);
+		mvwaddstr(editw, TABLINE, spacing * i + 4,  tab_names[i]);
+		mvwaddch(editw,  TABLINE, spacing * i + 11, UI_RBOXLINE_CHAR);
+		mvwaddch(editw,  TABLINE, spacing * i + 12, UI_URCORNER_CHAR);
 	}
 
-	mvwaddch(editw,  TABLINE+1, 16 * tab + 2, UI_LRCORNER_CHAR);
-	mvwaddstr(editw, TABLINE+1, 16 * tab + 3, "           ");
-	mvwaddch(editw,  TABLINE+1, 16 * tab + 14, UI_LLCORNER_CHAR);
+	mvwaddch(editw,  TABLINE+1, spacing * tab + 2, UI_LRCORNER_CHAR);
+	mvwaddstr(editw, TABLINE+1, spacing * tab + 3, "         ");
+	mvwaddch(editw,  TABLINE+1, spacing * tab + 12, UI_LLCORNER_CHAR);
 }
 
 void
@@ -144,7 +147,8 @@ print_editor_header(int item)
 	else
 		snprintf(header, EDITW_COLS, "%s", database[item][NAME]);
 
-	mvwaddstr(editw, 0, (EDITW_COLS - strlen(header)) / 2,
+	fprintf(stderr, "%d\n", strwidth(header));
+	mvwaddstr(editw, 0, (EDITW_COLS - strwidth(header)) / 2,
 			header);
 
 	free(header);
@@ -369,6 +373,8 @@ edit_undo(int item, int mode)
 				my_free(backup);
 			}
 			break;
+		default:
+			assert(0);
 	}
 }
 
@@ -394,6 +400,7 @@ edit_loop(int item)
 		case 'a': tab = TAB_ADDRESS; break;
 		case 'p': tab = TAB_PHONE; break;
 		case 'o': tab = TAB_OTHER; break;
+		case 'C': tab = TAB_CUSTOM; break;
 		case 'h':
 		case KEY_LEFT: tab = tab == 0 ? MAX_TAB : tab - 1;
 			       break;
