@@ -1,6 +1,6 @@
 
 /*
- * $Id: filter.c,v 1.28 2003/11/20 12:58:34 jheinonen Exp $
+ * $Id: filter.c,v 1.29 2004/01/23 07:14:32 jheinonen Exp $
  *
  * by JH <jheinonen@users.sourceforge.net>
  *
@@ -646,7 +646,7 @@ mutt_read_line(FILE *in, char **alias, char **rest)
 	}
 
 	strncpy(*alias, tmp, ptr - tmp - 1);
-	*(*alias + (ptr - tmp)) = 0;
+	*(*alias + (ptr - tmp - 1)) = 0;
 
 	while(ISSPACE(*ptr))
 		ptr++;
