@@ -1,6 +1,6 @@
 
 /*
- * $Id: options.c,v 1.18 2003/09/29 13:08:28 jheinonen Exp $
+ * $Id: options.c,v 1.21 2003/12/05 18:11:55 jheinonen Exp $
  *
  * by JH <jheinonen@users.sourceforge.net>
  *
@@ -257,6 +257,8 @@ opt_set_set_option(char *var, char *p, struct option *opt)
 			else
 				return "invalid value";
 			break;
+		default:
+			assert(0);
 	}
 	
 	return NULL;
@@ -283,12 +285,39 @@ opt_parse_set(buffer *b)
 	return "unknown option";
 }
 
+#include "database.h" /* needed for change_custom_field_name */
+
+static char *
+opt_parse_customfield(buffer *b)
+{
+	char *p, num[5];
+	int n;
+	size_t len;
+
+	find_token_start(b);
+	p = b -> ptr;
+	find_token_end(b);
+
+	memset(num, 0, sizeof(num));
+
+	len = (b -> ptr - p);
+	strncpy(num, p, min(sizeof(num) - 1, len));
+	n = safe_atoi(num);
+
+	find_token_start(b);
+
+	if(change_custom_field_name(b->ptr, n) == -1)
+		return "invalid custom field number";
+
+	return NULL;
+}
 
 static struct {
 	char *token;
 	char * (*func) (buffer *line);
 } opt_parsers[] = {
 	{ "set", opt_parse_set },
+	{ "customfield", opt_parse_customfield },
 	{ NULL }
 };
 
