@@ -1,6 +1,6 @@
 
 /*
- * $Id: ui.c,v 1.26 2003/05/30 16:24:20 jheinonen Exp $
+ * $Id: ui.c,v 1.29 2003/11/06 17:32:00 jheinonen Exp $
  *
  * by JH <jheinonen@users.sourceforge.net>
  *
@@ -383,7 +383,8 @@ get_commands()
 		can_resize = FALSE; /* it's not safe to resize anymore */
 		switch( ch ) {
 			case 'q': return;
-			case 'Q': print_stderr(selected_items() ?
+			case 'Q': quit_abook(QUIT_DONTSAVE);	break;
+			case 'P': print_stderr(selected_items() ?
 						  -1 : list_current_item());
 				  return;
 			case '?':
@@ -395,6 +396,7 @@ get_commands()
 			case KEY_DC:
 			case 'd':
 			case 'r': ui_remove_items();	break;
+			case 'D': duplicate_item();	break;
 			case 12: refresh_screen();	break;
 
 			case 'k':
@@ -420,8 +422,9 @@ get_commands()
 
 			case 'o': ui_open_datafile();	break;
 
-			case 's': sort_database();	break;
+			case 's': sort_by_field(NAME);	break;
 			case 'S': sort_surname();	break;
+			case 'F': sort_by_field(-1);	break;
 
 			case '/': ui_find(0);		break;
 			case '\\': ui_find(1);		break;
